@@ -130,7 +130,8 @@ sub _run {
     else {
 
         # it's a module
-        my $module = CPAN::Shell->expand( 'Module', $self->source );
+        my $type = $self->source =~ /^Bundle/ ? 'Bundle' : 'Module';
+        my $module = CPAN::Shell->expand( $type, $self->source );
 
         unless ($module) {
             $self->log->warn( "can't find "
@@ -161,6 +162,10 @@ sub _run {
     if ( $name eq 'perl' ) {
         $self->log->warn( 'perl itself contains ' . $self->source . ', will not process');
         return -1;
+    } 
+    if (!$name ) {
+        $self->log->warn("You asked to install ".$self->source. " but it isn't on the CPAN. Skipping");
+        return -1;
     }
 
     Shipwright::Util->select('stdout');
@@ -169,6 +174,7 @@ sub _run {
     $self->_update_map( $self->source, 'cpan-' . $name );
 
     $self->source($distribution->get_file_onto_local_disk);
+
     return 1;
 }
 
